pitchtools.IntervalSet
======================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalSet.IntervalSet

.. autoclass:: abjad.tools.pitchtools.IntervalSet.IntervalSet

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.copy
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.difference
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.from_selection
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.intersection
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.isdisjoint
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.issubset
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.issuperset
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.item_class
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.items
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.symmetric_difference
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.union
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__and__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__contains__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__eq__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__format__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__ge__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__gt__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__hash__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__iter__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__le__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__len__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__lt__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__ne__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__or__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__repr__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__str__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__sub__
      ~abjad.tools.pitchtools.IntervalSet.IntervalSet.__xor__

Bases
-----

- :py:class:`pitchtools.Set <abjad.tools.pitchtools.Set.Set>`

- :py:class:`datastructuretools.TypedFrozenset <abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalSet.IntervalSet.item_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalSet.IntervalSet.items
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.union
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSet.IntervalSet.__xor__
   :noindex:
